Mon 26JanTest application details - by chrisv from #3863 (Viewport test)

## Mon 26JanTest

### Application progress

First name: |
Last name: |
Email: |
Responsible RM: |
Status: |
Applic’n rec’d |
Stage 1 mtg | @
| Confirmed on
| Attended Yes No
| Hard-copy given Yes No
| Handover on
Stage 2 mtg | @ Confirmed on Contacts: Postcode areas: Document explanations given Yes No Franchisee contacts given Yes No Finance options given Yes No Financials given Yes No Business plan given Yes No Agreement given Yes No Disclosure letter given Yes No Medical letter given Yes No Attended Yes No
Site visit | @ Site visit contact Confirmed on Attended Yes No
Director interview | @ Confirmed on Attended Yes No Financials Recd Yes No Business plan Recd Yes No Agreement Recd Yes No Disclosure letter Recd Yes No Medical letter Recd Yes No Accept/decline sent on